@@ -61,8 +61,10 @@ isPackageNamespace <- function(env) {
   if (!is.environment(env)) return(FALSE)
   name <- environmentName(env)
   if (name == "base") return(TRUE)
-  packageName <- env$.packageName
-  if (identical(name, packageName)) return(TRUE)
+  if (exists(".packageName", mode = "character", envir = env, inherits = FALSE)) {
+    packageName <- get(".packageName", mode = "character", envir = env, inherits = FALSE)
+    if (identical(name, packageName)) return(TRUE)
+  }
   if (!grepl("^package:", name)) return(FALSE)
   (name %in% search())
 }
@@ -128,6 +130,11 @@ hexpr <- function(expr, trim = TRUE, collapse = "; ", max_head = 6L,
 } # hexpr()
 
 
+now <- function(x = Sys.time(), format = "[%H:%M:%OS3] ") {
+  ## format(x, format = format) ## slower
+  format(as.POSIXlt(x, tz = ""), format = format)
+}
+
 ## From future 1.3.0
 mdebug <- function(...) {
   if (!getOption("globals.debug", FALSE)) return(invisible(FALSE))
@@ -135,6 +142,12 @@ mdebug <- function(...) {
   invisible(TRUE)
 } ## mdebug()
 
+
+mdebugf <- function(..., appendLF = TRUE, prefix = now(), debug = getOption("globals.debug", FALSE)) {
+  if (!debug) return()
+  message(prefix, sprintf(...), appendLF = appendLF)
+}
+
 #' @importFrom utils capture.output str
 mstr <- function(...) {
   bfr <- capture.output(str(...))
@@ -147,21 +160,12 @@ envname <- function(env) {
   if (!is.environment(env)) return(NA_character_)
   name <- environmentName(env)
   if (name == "") {
-    class <- class(env)
-    if (identical(class, "environment")) {
-      ## e.g. new.env()
-      name <- capture.output(print(env))
-    } else {
-      ## It might be that 'env' is on a class that extends 'environment',
-      ## e.g. R.oo::Object() or R6::R6Class().
-      ## IMPORTANT: The unset class must be temporary, because changing
-      ## the class of an environment will
-      name <- local({
-        on.exit(class(env) <- class)
-        class(env) <- NULL
-        capture.output(print(env))
-      })	
-    }
+    ## NOTE: I might be that:
+    ## 1. 'env' is of a class that extends 'environment', e.g.
+    ##    R.oo::Object() or R6::R6Class(), or
+    ## 2. another package defines print() for 'environment'
+    ## Because of this, we call print.default() instead of generic print().
+    name <- capture.output(print.default(env))
     if (length(name) > 1L) name <- name[1]
     name <- gsub("(.*: |>)", "", name)
   } else {
@@ -171,16 +175,20 @@ envname <- function(env) {
   name
 }
 
-## When 'default' is specified, this is 30x faster than
-## base::getOption().  The difference is that here we use
-## use names(.Options) whereas in 'base' names(options())
-## is used.
-getOption <- local({
-  go <- base::getOption
-  function(x, default = NULL) {
-    if (missing(default) || match(x, table = names(.Options), nomatch = 0L) > 0L) go(x) else default
-  }
-})
+commaq <- function(x, sep = ", ") paste(sQuote(x), collapse = sep)
+
+if (getRversion() < "4.0.0") {
+  ## When 'default' is specified, this is 30x faster than
+  ## base::getOption().  The difference is that here we use
+  ## use names(.Options) whereas in 'base' names(options())
+  ## is used.
+  getOption <- local({
+    go <- base::getOption
+    function(x, default = NULL) {
+      if (missing(default) || match(x, table = names(.Options), nomatch = 0L) > 0L) go(x) else default
+    }
+  })
+}
 
 stop_if_not <- function(...) {
   res <- list(...)
